Fuzzy filtering for scripts. Filter module for nrs.
Provides fuzzy matching and filtering for script names and descriptions.
Structs
- Fuzzy
Matcher - Fuzzy matcher for script filtering.
Functions
- filter_
scripts - Filter scripts based on a query.
- filter_
scripts_ with_ matcher - Filter scripts using the FuzzyMatcher instance.
- get_
match_ indices - Get the indices of matched characters in the text.
- match_
score - Get the match score for a query against text.
- matches
- Check if a query matches text (simple boolean check).