execute_workspace_script

Function execute_workspace_script 

pub fn execute_workspace_script(
    runner: Runner,
    workspace: &str,
    script: &str,
    args: &[String],
    project_dir: &Path,
    dry_run: bool,
) -> Result<ExecutionResult>
Execute a workspace script with the given runner.

This runs a script in a specific workspace package from the monorepo root.

Arguments

  • runner - The package manager to use
  • workspace - The workspace name (package name)
  • script - The script name to run
  • args - Additional arguments to pass to the script
  • project_dir - The project directory (monorepo root) to run in
  • dry_run - If true, print the command without executing

Errors

Returns an error if the script fails to execute.