GridLayout

Struct GridLayout 

pub struct GridLayout {
    pub columns: usize,
    pub rows: usize,
    pub column_width: u16,
    pub visible_items: usize,
}
Calculate grid layout for scripts.

Fields

columns: usize

Number of columns.

rows: usize

Number of rows.

column_width: u16

Width of each column.

visible_items: usize

Total visible items.

Implementations

Source

impl GridLayout

pub fn new(area: Rect, total_items: usize) -> Self

Create a new grid layout.

pub fn position(&self, index: usize) -> (usize, usize)

Get the row and column for a given index.

pub fn index(&self, row: usize, col: usize) -> usize

Get the index for a given row and column.

pub fn is_visible(&self, index: usize, scroll_offset: usize) -> bool

Check if an index is visible.

pub fn display_position( &self, index: usize, scroll_offset: usize, ) -> Option<(usize, usize)>

Get the display position for an index (accounting for scroll).