pub struct EmptyScripts<'a> { /* private fields */ }Expand description
Empty state widget when no scripts are available.
Implementations
Sourceimpl<'a> EmptyScripts<'a>
impl<'a> EmptyScripts<'a>
Sourcepub fn with_hint(message: &'a str, hint: &'a str, theme: &'a Theme) -> Self
pub fn with_hint(message: &'a str, hint: &'a str, theme: &'a Theme) -> Self
Create a new empty scripts widget with a hint.
Sourcepub fn no_scripts(theme: &'a Theme) -> Self
pub fn no_scripts(theme: &'a Theme) -> Self
Create for no scripts found.
Sourcepub fn no_matches(theme: &'a Theme) -> Self
pub fn no_matches(theme: &'a Theme) -> Self
Create for no filter matches.
Sourcepub fn no_matches_for(filter: &str, theme: &'a Theme) -> Self
pub fn no_matches_for(filter: &str, theme: &'a Theme) -> Self
Create for filter with specific query that has no matches.
Sourcepub fn all_excluded(theme: &'a Theme) -> Self
pub fn all_excluded(theme: &'a Theme) -> Self
Create for all scripts excluded.