pub fn check_terminal_size() -> Option<TerminalSize>Expand description
Check the terminal size.
Returns the current terminal size, or None if it cannot be determined.
pub fn check_terminal_size() -> Option<TerminalSize>Check the terminal size.
Returns the current terminal size, or None if it cannot be determined.