cleanup_terminal

Function cleanup_terminal 

pub fn cleanup_terminal() -> Result<()>
Cleanup terminal completely.

This function should be called when the application exits to ensure the terminal is in a clean state:

  • Disables raw mode
  • Leaves alternate screen
  • Shows cursor

This is similar to prepare_for_script_execution but doesn’t check raw mode status first - it always tries to clean up.

Errors

Returns an error if terminal cleanup fails.