disable_raw_mode

Function disable_raw_mode 

pub fn disable_raw_mode() -> Result<()>
Disable raw mode.

Restores the terminal to its normal state where input is line-buffered and echoed.

Errors

Returns an error if raw mode cannot be disabled.