enable_raw_mode

Function enable_raw_mode 

pub fn enable_raw_mode() -> Result<()>
Enable raw mode for TUI.

This enables character-by-character input without echo, which is required for TUI applications.

Errors

Returns an error if raw mode cannot be enabled.