leave_alternate_screen

Function leave_alternate_screen 

pub fn leave_alternate_screen() -> Result<()>
Leave the alternate screen buffer.

Restores the original terminal content that was saved when entering the alternate screen.

Errors

Returns an error if the alternate screen cannot be left.