Module filter

Module filter 

Fuzzy filtering for scripts. Filter module for nrs.

Provides fuzzy matching and filtering for script names and descriptions.

Structs

FuzzyMatcher
Fuzzy matcher for script filtering.

Functions

filter_scripts
Filter scripts based on a query.
filter_scripts_with_matcher
Filter scripts using the FuzzyMatcher instance.
get_match_indices
Get the indices of matched characters in the text.
match_score
Get the match score for a query against text.
matches
Check if a query matches text (simple boolean check).