pub enum Runner {
Npm,
Yarn,
Pnpm,
Bun,
}Expand description
Supported package managers.
Variants
Npm
Node Package Manager (npm)
Yarn
Yarn package manager
Pnpm
pnpm - Fast, disk space efficient package manager
Bun
Bun - Fast all-in-one JavaScript runtime
Implementations
Sourceimpl Runner
impl Runner
Sourcepub fn executable(&self) -> &'static str
pub fn executable(&self) -> &'static str
Get the executable name for this runner.
Sourcepub fn run_prefix(&self) -> &'static str
pub fn run_prefix(&self) -> &'static str
Get the base run command (without script name).
Returns the command prefix used to run scripts:
- npm: “npm run”
- yarn: “yarn”
- pnpm: “pnpm”
- bun: “bun run”
Sourcepub fn run_command(&self, script: &str) -> Vec<String>
pub fn run_command(&self, script: &str) -> Vec<String>
Get the command to run a script as a vector of arguments.
Examples
use npm_run_scripts::package::Runner;
let cmd = Runner::Npm.run_command("dev");
assert_eq!(cmd, vec!["npm", "run", "dev"]);
let cmd = Runner::Yarn.run_command("build");
assert_eq!(cmd, vec!["yarn", "build"]);Sourcepub fn run_command_with_args(
&self,
script: &str,
args: &[String],
) -> Vec<String>
pub fn run_command_with_args( &self, script: &str, args: &[String], ) -> Vec<String>
Get the command to run a script with additional arguments.
Arguments
script- The script name to runargs- Additional arguments to pass to the script
Examples
use npm_run_scripts::package::Runner;
let args = vec!["--watch".to_string(), "--coverage".to_string()];
let cmd = Runner::Npm.run_command_with_args("test", &args);
assert_eq!(cmd, vec!["npm", "run", "test", "--", "--watch", "--coverage"]);Sourcepub fn format_command(&self, script: &str) -> String
pub fn format_command(&self, script: &str) -> String
Format the run command as a string for display.
Examples
use npm_run_scripts::package::Runner;
assert_eq!(Runner::Npm.format_command("dev"), "npm run dev");
assert_eq!(Runner::Yarn.format_command("build"), "yarn build");Sourcepub fn format_command_with_args(&self, script: &str, args: &[String]) -> String
pub fn format_command_with_args(&self, script: &str, args: &[String]) -> String
Format the run command with arguments as a string for display.
Examples
use npm_run_scripts::package::Runner;
let args = vec!["--watch".to_string()];
assert_eq!(
Runner::Npm.format_command_with_args("test", &args),
"npm run test -- --watch"
);Sourcepub fn display_name(&self) -> &'static str
pub fn display_name(&self) -> &'static str
Get the display name for the runner.
Sourcepub fn workspace_command(&self, workspace: &str, script: &str) -> Vec<String>
pub fn workspace_command(&self, workspace: &str, script: &str) -> Vec<String>
Get the command to run a workspace script.
Arguments
workspace- The workspace/package namescript- The script name to run
Sourcepub fn workspace_command_with_args(
&self,
workspace: &str,
script: &str,
args: &[String],
) -> Vec<String>
pub fn workspace_command_with_args( &self, workspace: &str, script: &str, args: &[String], ) -> Vec<String>
Get the command to run a workspace script with additional arguments.
Arguments
workspace- The workspace/package namescript- The script name to runargs- Additional arguments to pass to the script
Sourcepub fn format_workspace_command(&self, workspace: &str, script: &str) -> String
pub fn format_workspace_command(&self, workspace: &str, script: &str) -> String
Format the workspace run command as a string for display.