pub fn execute_workspace_script(
runner: Runner,
workspace: &str,
script: &str,
args: &[String],
project_dir: &Path,
dry_run: bool,
) -> Result<ExecutionResult>Expand description
Execute a workspace script with the given runner.
This runs a script in a specific workspace package from the monorepo root.
Arguments
runner- The package manager to useworkspace- The workspace name (package name)script- The script name to runargs- Additional arguments to pass to the scriptproject_dir- The project directory (monorepo root) to run indry_run- If true, print the command without executing
Errors
Returns an error if the script fails to execute.