Path and terminal utilities. Utility module for nrs.
Common utilities for paths, terminal handling, and other helpers.
Structs
- Terminal
Size - Terminal size information.
Constants
- MAX_
SEARCH_ DEPTH - Maximum number of parent directories to search.
- MIN_
HEIGHT - MIN_
WIDTH - Minimum terminal dimensions.
Functions
- check_
terminal_ size - Check the terminal size.
- cleanup_
terminal - Cleanup terminal completely.
- config_
dir - Get the config directory for nrs.
- disable_
raw_ mode - Disable raw mode.
- enable_
raw_ mode - Enable raw mode for TUI.
- enter_
alternate_ screen - Enter the alternate screen buffer.
- find_
package_ json - Find the package.json file starting from the given directory.
- find_
project_ root - Find the project root (directory containing package.json).
- global_
config_ file - Get the global config file path.
- hide_
cursor - Hide the cursor.
- history_
file - Get the history file path.
- is_
raw_ mode_ enabled - Check if the terminal is currently in raw mode.
- leave_
alternate_ screen - Leave the alternate screen buffer.
- local_
config_ file - Find local config file in project directory.
- prepare_
for_ script_ execution - Prepare terminal for script execution.
- restore_
for_ tui - Restore terminal for TUI.
- show_
cursor - Show the cursor.