pub fn leave_alternate_screen() -> Result<()>Expand description
Leave the alternate screen buffer.
Restores the original terminal content that was saved when entering the alternate screen.
Errors
Returns an error if the alternate screen cannot be left.